synapse.app package — Synapse 1.0 documentation

# synapse.app package

## Submodules

- synapse.app.homeserver module

## Module contents

`synapse.app.` `check_bind_error`(e, address, bind_addresses)

  This method checks an exception occurred while binding on 0.0.0.0. If :: is specified in the bind addresses a warning is shown. The exception is still raised otherwise.

  Binding on both 0.0.0.0 and :: causes an exception on Linux and macOS because :: binds on both IPv4 and IPv6 (as per RFC 3493). When binding on 0.0.0.0 after :: this can safely be ignored.

  Parameters: | e (Exception) – Exception that was caught. address (str) – Address on which binding was attempted. bind_addresses (list) – Addresses on which the service listens.